django-holonet |frigg| |coverage| |version| |python|
====================================================

Django package used to interact with holonet.


Quickstart
----------

Install django-holonet:

    $ pip install django-holonet

Documentation
-------------

`Full documentation available on ReadTheDocs`_


-------------------

MIT © Abakus Webkom


.. |frigg| image:: https://ci.frigg.io/badges/webkom/django-holonet/
    :target: https://ci.frigg.io/webkom/django-holonet/last/

.. |coverage| image:: https://ci.frigg.io/badges/coverage/webkom/django-holonet/
    :target: https://ci.frigg.io/webkom/django-holonet/last/

.. |version| image:: https://pypip.in/version/django-holonet/badge.png?style=flat
    :target: https://pypi.python.org/pypi/django-holonet/
    :alt: Latest Version

.. |python| image:: https://pypip.in/py_versions/django-holonet/badge.png?style=flat
    :target: https://pypi.python.org/pypi/django-holonet/
    :alt: Supported Python versions

.. |docs| image:: https://readthedocs.org/projects/django-holonet/badge/?version=latest
    :target: http://django-holonet.readthedocs.org/
    :alt: Documentation Status

.. _Full documentation available on ReadTheDocs: http://django-holonet.readthedocs.org/
